==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GroupDataDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GroupDataDescription } from "./GroupDataDescription";
/**
 * @hidden
 */
var GroupDataDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GroupDataDescriptionMetadata, _super);
    function GroupDataDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GroupDataDescriptionMetadata.b = function (a) {
        if (GroupDataDescriptionMetadata.a == null) {
            GroupDataDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GroupDataDescriptionMetadata.c(GroupDataDescriptionMetadata.a);
        }
        if (a.g(GroupDataDescriptionMetadata.a)) {
            return;
        }
        a.s(GroupDataDescriptionMetadata.a);
    };
    GroupDataDescriptionMetadata.c = function (a) {
        a.item("GroupName", "String");
        a.item("GroupValueRef", "(w:GroupValue,wf:GroupValue)DataRef");
        a.item("FormattedText", "String");
    };
    GroupDataDescriptionMetadata.d = function (a) {
        GroupDataDescriptionMetadata.b(a);
        a.u("GroupData", function () { return new GroupDataDescription(); });
        a.t("GroupData", GroupDataDescriptionMetadata.a);
    };
    GroupDataDescriptionMetadata.$t = markType(GroupDataDescriptionMetadata, 'GroupDataDescriptionMetadata');
    GroupDataDescriptionMetadata.a = null;
    return GroupDataDescriptionMetadata;
}(Base));
export { GroupDataDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GroupDataDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GroupDataDescription } from "./GroupDataDescription";
/**
 * @hidden
 */
var GroupDataDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GroupDataDescriptionMetadata, _super);
    function GroupDataDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GroupDataDescriptionMetadata.b = function (a) {
        if (GroupDataDescriptionMetadata.a == null) {
            GroupDataDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GroupDataDescriptionMetadata.c(GroupDataDescriptionMetadata.a);
        }
        if (a.j(GroupDataDescriptionMetadata.a)) {
            return;
        }
        a.y(GroupDataDescriptionMetadata.a);
    };
    GroupDataDescriptionMetadata.c = function (a) {
        a.item("GroupName", "String");
        a.item("GroupValueRef", "(w:GroupValue,wf:GroupValue)DataRef");
        a.item("FormattedText", "String");
    };
    GroupDataDescriptionMetadata.d = function (a) {
        GroupDataDescriptionMetadata.b(a);
        a.aa("GroupData", function () { return new GroupDataDescription(); });
        a.z("GroupData", GroupDataDescriptionMetadata.a);
    };
    GroupDataDescriptionMetadata.$t = markType(GroupDataDescriptionMetadata, 'GroupDataDescriptionMetadata');
    GroupDataDescriptionMetadata.a = null;
    return GroupDataDescriptionMetadata;
}(Base));
export { GroupDataDescriptionMetadata };
